@@ -4,8 +4,8 @@
 ;; Author: <github.com/Anoncheg1,codeberg.org/Anoncheg>
 ;; Keywords:  color, windows, faces, buffer, background
 ;; URL: https://codeberg.org/Anoncheg/selected-window-contrast
-;; Package-Version: 20260209.1053
-;; Package-Revision: d8bbb64d21ae
+;; Package-Version: 20260212.1150
+;; Package-Revision: 7936b00a5822
 ;; Created: 11 dec 2024
 ;; Package-Requires: ((emacs "29.4"))
 ;; SPDX-License-Identifier: AGPL-3.0-or-later
@@ -28,13 +28,11 @@
 ;; see <https://www.gnu.org/licenses/agpl-3.0.en.html>.
 
 ;;; Commentary:
-;; It Loop windows at frame, measure and adjust contrast.  Allow to
-;;  set color (face) of background and text by comparing their
-;;  brightness.
-;; This is useful for changing themes during the daytime (circadian
-;;  package) and for highlighting selected window.  Also this works
-;;  for modeline.
-;;  We also highligh cursor position, this may be disabled witha
+;; Highlight selected window by adjusting contrast of text
+;;  "foreground" and background.
+;; Working good if you switch temes frequently, contrast will be kept.
+;; Also this works for modeline.
+;;  We also highligh cursor position, this may be disabled with
 ;;  M-x customize-variable RET selected-window-contrast-text-switch-mode
 
 ;; Usage:
@@ -65,7 +63,7 @@
 
 ;; Donate:
 ;; - BTC (Bitcoin) address: 1CcDWSQ2vgqv5LxZuWaHGW52B9fkT5io25
-;; - USDT (Tether) address: TVoXfYMkVYLnQZV3mGZ6GvmumuBfGsZzsN
+;; - USDT (Tether TRX-TRON) address: TVoXfYMkVYLnQZV3mGZ6GvmumuBfGsZzsN
 ;; - TON (Telegram) address: UQC8rjJFCHQkfdp7KmCkTZCb5dGzLFYe2TzsiZpfsnyTFt9D
 
 ;; Other packages:
@@ -118,6 +116,11 @@ in [0-1] range."
   :group 'selected-window-contrast
   :type 'number)
 
+(defcustom selected-window-contrast-region-timeout 0.5
+  "Hightlight cursor position: Second for which to show rectangle around."
+  :group 'selected-window-contrast
+  :type 'float)
+
 (defun selected-window-contrast--get-current-colors ()
   "Get current text and background color of default face.
 Returns list: (foreground background), both strings."
@@ -259,10 +262,13 @@ Use `rectangle-mark-mode'.  Deactivate rectangle after 1 second or less."
            (rectangle-forward-char 8)
            (rectangle-exchange-point-and-mark))
     ;; Start timer to deactivate mark and rectangle mode.
-    (run-with-timer 0.5 nil (lambda ()
-                              (when (region-active-p)
-                                ;; (exchange-point-and-mark)
-                                (deactivate-mark))))))
+    (run-with-timer selected-window-contrast-region-timeout
+                    nil (lambda (buf)
+                          (with-current-buffer buf
+                            (when (region-active-p)
+                              ;; (exchange-point-and-mark)
+                              (deactivate-mark))))
+                    (current-buffer))))
 
 (defun selected-window-contrast-highlight-selected-window-with-timeout ()
   "Highlight not selected windows with a different background color.
